@@ -19,19 +19,19 @@ from functools import wraps, partial, total_ordering
 from heapq import heappush, heappop
 import io
 import logging
-import six
-from six.moves import range
 import socket
 import struct
 import sys
 from threading import Thread, Event, RLock, Condition
 import time
 import ssl
+import weakref
+
 
 if 'gevent.monkey' in sys.modules:
     from gevent.queue import Queue, Empty
 else:
-    from six.moves.queue import Queue, Empty  # noqa
+    from queue import Queue, Empty  # noqa
 
 from cassandra import ConsistencyLevel, AuthenticationFailed, OperationTimedOut, ProtocolVersion
 from cassandra.marshal import int32_pack
@@ -42,11 +42,15 @@ from cassandra.protocol import (ReadyMessage, AuthenticateMessage, OptionsMessag
                                 AuthResponseMessage, AuthChallengeMessage,
                                 AuthSuccessMessage, ProtocolException,
                                 RegisterMessage, ReviseRequestMessage)
+from cassandra.segment import SegmentCodec, CrcException
 from cassandra.util import OrderedDict
 
 
 log = logging.getLogger(__name__)
 
+segment_codec_no_compression = SegmentCodec()
+segment_codec_lz4 = None
+
 # We use an ordered dictionary and specifically add lz4 before
 # snappy so that lz4 will be preferred. Changing the order of this
 # will change the compression preferences for the driver.
@@ -88,6 +92,7 @@ else:
         return lz4_block.decompress(byts[3::-1] + byts[4:])
 
     locally_supported_compressions['lz4'] = (lz4_compress, lz4_decompress)
+    segment_codec_lz4 = SegmentCodec(lz4_compress, lz4_decompress)
 
 try:
     import snappy
@@ -426,6 +431,10 @@ class ProtocolError(Exception):
     pass
 
 
+class CrcMismatchException(ConnectionException):
+    pass
+
+
 class ContinuousPagingState(object):
     """
      A class for specifying continuous paging state, only supported starting with DSE_V2.
@@ -594,11 +603,59 @@ def defunct_on_error(f):
 
 DEFAULT_CQL_VERSION = '3.0.0'
 
-if six.PY3:
-    def int_from_buf_item(i):
-        return i
-else:
-    int_from_buf_item = ord
+
+class _ConnectionIOBuffer(object):
+    """
+    Abstraction class to ease the use of the different connection io buffers. With
+    protocol V5 and checksumming, the data is read, validated and copied to another
+    cql frame buffer.
+    """
+    _io_buffer = None
+    _cql_frame_buffer = None
+    _connection = None
+    _segment_consumed = False
+
+    def __init__(self, connection):
+        self._io_buffer = io.BytesIO()
+        self._connection = weakref.proxy(connection)
+
+    @property
+    def io_buffer(self):
+        return self._io_buffer
+
+    @property
+    def cql_frame_buffer(self):
+        return self._cql_frame_buffer if self.is_checksumming_enabled else \
+            self._io_buffer
+
+    def set_checksumming_buffer(self):
+        self.reset_io_buffer()
+        self._cql_frame_buffer = io.BytesIO()
+
+    @property
+    def is_checksumming_enabled(self):
+        return self._connection._is_checksumming_enabled
+
+    @property
+    def has_consumed_segment(self):
+        return self._segment_consumed;
+
+    def readable_io_bytes(self):
+        return self.io_buffer.tell()
+
+    def readable_cql_frame_bytes(self):
+        return self.cql_frame_buffer.tell()
+
+    def reset_io_buffer(self):
+        self._io_buffer = io.BytesIO(self._io_buffer.read())
+        self._io_buffer.seek(0, 2)  # 2 == SEEK_END
+
+    def reset_cql_frame_buffer(self):
+        if self.is_checksumming_enabled:
+            self._cql_frame_buffer = io.BytesIO(self._cql_frame_buffer.read())
+            self._cql_frame_buffer.seek(0, 2)  # 2 == SEEK_END
+        else:
+            self.reset_io_buffer()
 
 
 class Connection(object):
@@ -625,6 +682,7 @@ class Connection(object):
 
     # The current number of operations that are in flight. More precisely,
     # the number of request IDs that are currently in use.
+    # This includes orphaned requests.
     in_flight = 0
 
     # Max concurrent requests allowed per connection. This is set optimistically high, allowing
@@ -642,6 +700,20 @@ class Connection(object):
     # request_ids set
     highest_request_id = 0
 
+    # Tracks the request IDs which are no longer waited on (timed out), but
+    # cannot be reused yet because the node might still send a response
+    # on this stream
+    orphaned_request_ids = None
+
+    # Set to true if the orphaned stream ID count cross configured threshold
+    # and the connection will be replaced
+    orphaned_threshold_reached = False
+
+    # If the number of orphaned streams reaches this threshold, this connection
+    # will become marked and will be replaced with a new connection by the
+    # owning pool (currently, only HostConnection supports this)
+    orphaned_threshold = 3  * max_in_flight // 4
+
     is_defunct = False
     is_closed = False
     lock = None
@@ -656,28 +728,35 @@ class Connection(object):
 
     allow_beta_protocol_version = False
 
-    _iobuf = None
     _current_frame = None
 
     _socket = None
 
     _socket_impl = socket
-    _ssl_impl = ssl
 
     _check_hostname = False
     _product_type = None
 
+    _is_checksumming_enabled = False
+
+    _on_orphaned_stream_released = None
+
+    @property
+    def _iobuf(self):
+        # backward compatibility, to avoid any change in the reactors
+        return self._io_buffer.io_buffer
+
     def __init__(self, host='127.0.0.1', port=9042, authenticator=None,
                  ssl_options=None, sockopts=None, compression=True,
                  cql_version=None, protocol_version=ProtocolVersion.MAX_SUPPORTED, is_control_connection=False,
                  user_type_map=None, connect_timeout=None, allow_beta_protocol_version=False, no_compact=False,
-                 ssl_context=None):
+                 ssl_context=None, on_orphaned_stream_released=None):
 
         # TODO next major rename host to endpoint and remove port kwarg.
         self.endpoint = host if isinstance(host, EndPoint) else DefaultEndPoint(host, port)
 
         self.authenticator = authenticator
-        self.ssl_options = ssl_options.copy() if ssl_options else None
+        self.ssl_options = ssl_options.copy() if ssl_options else {}
         self.ssl_context = ssl_context
         self.sockopts = sockopts
         self.compression = compression
@@ -690,20 +769,27 @@ class Connection(object):
         self.no_compact = no_compact
         self._push_watchers = defaultdict(set)
         self._requests = {}
-        self._iobuf = io.BytesIO()
+        self._io_buffer = _ConnectionIOBuffer(self)
         self._continuous_paging_sessions = {}
         self._socket_writable = True
+        self.orphaned_request_ids = set()
+        self._on_orphaned_stream_released = on_orphaned_stream_released
 
         if ssl_options:
-            self._check_hostname = bool(self.ssl_options.pop('check_hostname', False))
-            if self._check_hostname:
-                if not getattr(ssl, 'match_hostname', None):
-                    raise RuntimeError("ssl_options specify 'check_hostname', but ssl.match_hostname is not provided. "
-                                       "Patch or upgrade Python to use this option.")
             self.ssl_options.update(self.endpoint.ssl_options or {})
         elif self.endpoint.ssl_options:
             self.ssl_options = self.endpoint.ssl_options
 
+        # PYTHON-1331
+        #
+        # We always use SSLContext.wrap_socket() now but legacy configs may have other params that were passed to ssl.wrap_socket()...
+        # and either could have 'check_hostname'.  Remove these params into a separate map and use them to build an SSLContext if
+        # we need to do so.
+        #
+        # Note the use of pop() here; we are very deliberately removing these params from ssl_options if they're present.  After this
+        # operation ssl_options should contain only args needed for the ssl_context.wrap_socket() call.
+        if not self.ssl_context and self.ssl_options:
+            self.ssl_context = self._build_ssl_context_from_options()
 
         if protocol_version >= 3:
             self.max_request_id = min(self.max_in_flight - 1, (2 ** 15) - 1)
@@ -770,21 +856,57 @@ class Connection(object):
         else:
             return conn
 
+    def _build_ssl_context_from_options(self):
+
+        # Extract a subset of names from self.ssl_options which apply to SSLContext creation
+        ssl_context_opt_names = ['ssl_version', 'cert_reqs', 'check_hostname', 'keyfile', 'certfile', 'ca_certs', 'ciphers']
+        opts = {k:self.ssl_options.get(k, None) for k in ssl_context_opt_names if k in self.ssl_options}
+
+        # Python >= 3.10 requires either PROTOCOL_TLS_CLIENT or PROTOCOL_TLS_SERVER so we'll get ahead of things by always
+        # being explicit
+        ssl_version = opts.get('ssl_version', None) or ssl.PROTOCOL_TLS_CLIENT
+        cert_reqs = opts.get('cert_reqs', None) or ssl.CERT_REQUIRED
+        rv = ssl.SSLContext(protocol=int(ssl_version))
+        rv.check_hostname = bool(opts.get('check_hostname', False))
+        rv.options = int(cert_reqs)
+
+        certfile = opts.get('certfile', None)
+        keyfile = opts.get('keyfile', None)
+        if certfile:
+            rv.load_cert_chain(certfile, keyfile)
+        ca_certs = opts.get('ca_certs', None)
+        if ca_certs:
+            rv.load_verify_locations(ca_certs)
+        ciphers = opts.get('ciphers', None)
+        if ciphers:
+            rv.set_ciphers(ciphers)
+
+        return rv
+
     def _wrap_socket_from_context(self):
-        ssl_options = self.ssl_options or {}
+
+        # Extract a subset of names from self.ssl_options which apply to SSLContext.wrap_socket (or at least the parts
+        # of it that don't involve building an SSLContext under the covers)
+        wrap_socket_opt_names = ['server_side', 'do_handshake_on_connect', 'suppress_ragged_eofs', 'server_hostname']
+        opts = {k:self.ssl_options.get(k, None) for k in wrap_socket_opt_names if k in self.ssl_options}
+
         # PYTHON-1186: set the server_hostname only if the SSLContext has
         # check_hostname enabled and it is not already provided by the EndPoint ssl options
-        if (self.ssl_context.check_hostname and
-                'server_hostname' not in ssl_options):
-            ssl_options = ssl_options.copy()
-            ssl_options['server_hostname'] = self.endpoint.address
-        self._socket = self.ssl_context.wrap_socket(self._socket, **ssl_options)
+        #opts['server_hostname'] = self.endpoint.address
+        if (self.ssl_context.check_hostname and 'server_hostname' not in opts):
+            server_hostname = self.endpoint.address
+            opts['server_hostname'] = server_hostname
+
+        return self.ssl_context.wrap_socket(self._socket, **opts)
 
     def _initiate_connection(self, sockaddr):
         self._socket.connect(sockaddr)
 
-    def _match_hostname(self):
-        ssl.match_hostname(self._socket.getpeercert(), self.endpoint.address)
+    # PYTHON-1331
+    #
+    # Allow implementations specific to an event loop to add additional behaviours
+    def _validate_hostname(self):
+        pass
 
     def _get_socket_addresses(self):
         address, port = self.endpoint.resolve()
@@ -805,16 +927,18 @@ class Connection(object):
             try:
                 self._socket = self._socket_impl.socket(af, socktype, proto)
                 if self.ssl_context:
-                    self._wrap_socket_from_context()
-                elif self.ssl_options:
-                    if not self._ssl_impl:
-                        raise RuntimeError("This version of Python was not compiled with SSL support")
-                    self._socket = self._ssl_impl.wrap_socket(self._socket, **self.ssl_options)
+                    self._socket = self._wrap_socket_from_context()
                 self._socket.settimeout(self.connect_timeout)
                 self._initiate_connection(sockaddr)
                 self._socket.settimeout(None)
+
+                # PYTHON-1331
+                #
+                # Most checking is done via the check_hostname param on the SSLContext.
+                # Subclasses can add additional behaviours via _validate_hostname() so
+                # run that here.
                 if self._check_hostname:
-                    self._match_hostname()
+                    self._validate_hostname()
                 sockerr = None
                 break
             except socket.error as err:
@@ -831,6 +955,16 @@ class Connection(object):
             for args in self.sockopts:
                 self._socket.setsockopt(*args)
 
+    def _enable_compression(self):
+        if self._compressor:
+            self.compressor = self._compressor
+
+    def _enable_checksumming(self):
+        self._io_buffer.set_checksumming_buffer()
+        self._is_checksumming_enabled = True
+        self._segment_codec = segment_codec_lz4 if self.compressor else segment_codec_no_compression
+        log.debug("Enabling protocol checksumming on connection (%s).", id(self))
+
     def close(self):
         raise NotImplementedError()
 
@@ -933,7 +1067,14 @@ class Connection(object):
         # queue the decoder function with the request
         # this allows us to inject custom functions per request to encode, decode messages
         self._requests[request_id] = (cb, decoder, result_metadata)
-        msg = encoder(msg, request_id, self.protocol_version, compressor=self.compressor, allow_beta_protocol_version=self.allow_beta_protocol_version)
+        msg = encoder(msg, request_id, self.protocol_version, compressor=self.compressor,
+                      allow_beta_protocol_version=self.allow_beta_protocol_version)
+
+        if self._is_checksumming_enabled:
+            buffer = io.BytesIO()
+            self._segment_codec.encode(buffer, msg)
+            msg = buffer.getvalue()
+
         self.push(msg)
         return len(msg)
 
@@ -1012,10 +1153,10 @@ class Connection(object):
 
     @defunct_on_error
     def _read_frame_header(self):
-        buf = self._iobuf.getvalue()
+        buf = self._io_buffer.cql_frame_buffer.getvalue()
         pos = len(buf)
         if pos:
-            version = int_from_buf_item(buf[0]) & PROTOCOL_VERSION_MASK
+            version = buf[0] & PROTOCOL_VERSION_MASK
             if version not in ProtocolVersion.SUPPORTED_VERSIONS:
                 raise ProtocolError("This version of the driver does not support protocol version %d" % version)
             frame_header = frame_header_v3 if version >= 3 else frame_header_v1_v2
@@ -1028,29 +1169,62 @@ class Connection(object):
                 self._current_frame = _Frame(version, flags, stream, op, header_size, body_len + header_size)
         return pos
 
-    def _reset_frame(self):
-        self._iobuf = io.BytesIO(self._iobuf.read())
-        self._iobuf.seek(0, 2)  # io.SEEK_END == 2 (constant not present in 2.6)
-        self._current_frame = None
+    @defunct_on_error
+    def _process_segment_buffer(self):
+        readable_bytes = self._io_buffer.readable_io_bytes()
+        if readable_bytes >= self._segment_codec.header_length_with_crc:
+            try:
+                self._io_buffer.io_buffer.seek(0)
+                segment_header = self._segment_codec.decode_header(self._io_buffer.io_buffer)
+
+                if readable_bytes >= segment_header.segment_length:
+                    segment = self._segment_codec.decode(self._iobuf, segment_header)
+                    self._io_buffer._segment_consumed = True
+                    self._io_buffer.cql_frame_buffer.write(segment.payload)
+                else:
+                    # not enough data to read the segment. reset the buffer pointer at the
+                    # beginning to not lose what we previously read (header).
+                    self._io_buffer._segment_consumed = False
+                    self._io_buffer.io_buffer.seek(0)
+            except CrcException as exc:
+                # re-raise an exception that inherits from ConnectionException
+                raise CrcMismatchException(str(exc), self.endpoint)
+        else:
+            self._io_buffer._segment_consumed = False
 
     def process_io_buffer(self):
         while True:
+            if self._is_checksumming_enabled and self._io_buffer.readable_io_bytes():
+                self._process_segment_buffer()
+                self._io_buffer.reset_io_buffer()
+
+            if self._is_checksumming_enabled and not self._io_buffer.has_consumed_segment:
+                # We couldn't read an entire segment from the io buffer, so return
+                # control to allow more bytes to be read off the wire
+                return
+
             if not self._current_frame:
                 pos = self._read_frame_header()
             else:
-                pos = self._iobuf.tell()
+                pos = self._io_buffer.readable_cql_frame_bytes()
 
             if not self._current_frame or pos < self._current_frame.end_pos:
+                if self._is_checksumming_enabled and self._io_buffer.readable_io_bytes():
+                    # We have a multi-segments message and we need to read more
+                    # data to complete the current cql frame
+                    continue
+
                 # we don't have a complete header yet or we
                 # already saw a header, but we don't have a
                 # complete message yet
                 return
             else:
                 frame = self._current_frame
-                self._iobuf.seek(frame.body_offset)
-                msg = self._iobuf.read(frame.end_pos - frame.body_offset)
+                self._io_buffer.cql_frame_buffer.seek(frame.body_offset)
+                msg = self._io_buffer.cql_frame_buffer.read(frame.end_pos - frame.body_offset)
                 self.process_msg(frame, msg)
-                self._reset_frame()
+                self._io_buffer.reset_cql_frame_buffer()
+                self._current_frame = None
 
     @defunct_on_error
     def process_msg(self, header, body):
@@ -1067,11 +1241,22 @@ class Connection(object):
                 decoder = paging_session.decoder
                 result_metadata = None
             else:
+                need_notify_of_release = False
+                with self.lock:
+                    if stream_id in self.orphaned_request_ids:
+                        self.in_flight -= 1
+                        self.orphaned_request_ids.remove(stream_id)
+                        need_notify_of_release = True
+                if need_notify_of_release and self._on_orphaned_stream_released:
+                    self._on_orphaned_stream_released()
+
                 try:
                     callback, decoder, result_metadata = self._requests.pop(stream_id)
                 # This can only happen if the stream_id was
                 # removed due to an OperationTimedOut
                 except KeyError:
+                    with self.lock:
+                        self.request_ids.append(stream_id)
                     return
 
         try:
@@ -1170,7 +1355,7 @@ class Connection(object):
                           remote_supported_compressions)
             else:
                 compression_type = None
-                if isinstance(self.compression, six.string_types):
+                if isinstance(self.compression, str):
                     # the user picked a specific compression type ('snappy' or 'lz4')
                     if self.compression not in remote_supported_compressions:
                         raise ProtocolError(
@@ -1185,11 +1370,19 @@ class Connection(object):
                             compression_type = k
                             break
 
-                # set the decompressor here, but set the compressor only after
-                # a successful Ready message
-                self._compression_type = compression_type
-                self._compressor, self.decompressor = \
-                    locally_supported_compressions[compression_type]
+                # If snappy compression is selected with v5+checksumming, the connection
+                # will fail with OTO. Only lz4 is supported
+                if (compression_type == 'snappy' and
+                        ProtocolVersion.has_checksumming_support(self.protocol_version)):
+                    log.debug("Snappy compression is not supported with protocol version %s and "
+                              "checksumming. Consider installing lz4. Disabling compression.", self.protocol_version)
+                    compression_type = None
+                else:
+                    # set the decompressor here, but set the compressor only after
+                    # a successful Ready message
+                    self._compression_type = compression_type
+                    self._compressor, self.decompressor = \
+                        locally_supported_compressions[compression_type]
 
         self._send_startup_message(compression_type, no_compact=self.no_compact)
 
@@ -1210,6 +1403,7 @@ class Connection(object):
     def _handle_startup_response(self, startup_response, did_authenticate=False):
         if self.is_defunct:
             return
+
         if isinstance(startup_response, ReadyMessage):
             if self.authenticator:
                 log.warning("An authentication challenge was not sent, "
@@ -1218,8 +1412,11 @@ class Connection(object):
                             self.authenticator.__class__.__name__)
 
             log.debug("Got ReadyMessage on new connection (%s) from %s", id(self), self.endpoint)
-            if self._compressor:
-                self.compressor = self._compressor
+            self._enable_compression()
+
+            if ProtocolVersion.has_checksumming_support(self.protocol_version):
+                self._enable_checksumming()
+
             self.connected_event.set()
         elif isinstance(startup_response, AuthenticateMessage):
             log.debug("Got AuthenticateMessage on new connection (%s) from %s: %s",
@@ -1231,6 +1428,10 @@ class Connection(object):
                           "if DSE authentication is configured with transitional mode" % (self.host,))
                 raise AuthenticationFailed('Remote end requires authentication')
 
+            self._enable_compression()
+            if ProtocolVersion.has_checksumming_support(self.protocol_version):
+                self._enable_checksumming()
+
             if isinstance(self.authenticator, dict):
                 log.debug("Sending credentials-based auth response on %s", self)
                 cm = CredentialsMessage(creds=self.authenticator)
