@@ -18,10 +18,7 @@ from cassandra.cluster import Cluster
 from tests import connection_class, EVENT_LOOP_MANAGER
 Cluster.connection_class = connection_class
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest  # noqa
+import unittest
 
 from packaging.version import Version
 import logging
@@ -33,7 +30,6 @@ import platform
 from threading import Event
 from subprocess import call
 from itertools import groupby
-import six
 import shutil
 
 from cassandra import OperationTimedOut, ReadTimeout, ReadFailure, WriteTimeout, WriteFailure, AlreadyExists,\
@@ -55,6 +51,14 @@ CLUSTER_NAME = 'test_cluster'
 SINGLE_NODE_CLUSTER_NAME = 'single_node'
 MULTIDC_CLUSTER_NAME = 'multidc_test_cluster'
 
+# When use_single_interface is specified ccm will assign distinct port numbers to each
+# node in the cluster.  This value specifies the default port value used for the first
+# node that comes up.
+#
+# TODO: In the future we may want to make this configurable, but this should only apply
+# if a non-standard port were specified when starting up the cluster.
+DEFAULT_SINGLE_INTERFACE_PORT=9046
+
 CCM_CLUSTER = None
 
 path = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'ccm')
@@ -338,7 +342,6 @@ lessthandse51 = unittest.skipUnless(DSE_VERSION and DSE_VERSION < Version('5.1')
 lessthandse60 = unittest.skipUnless(DSE_VERSION and DSE_VERSION < Version('6.0'), "DSE version less than 6.0 required")
 
 pypy = unittest.skipUnless(platform.python_implementation() == "PyPy", "Test is skipped unless it's on PyPy")
-notpy3 = unittest.skipIf(sys.version_info >= (3, 0), "Test not applicable for Python 3.x runtime")
 requiresmallclockgranularity = unittest.skipIf("Windows" in platform.system() or "asyncore" in EVENT_LOOP_MANAGER,
                                                "This test is not suitible for environments with large clock granularity")
 requiressimulacron = unittest.skipIf(SIMULACRON_JAR is None or CASSANDRA_VERSION < Version("2.1"), "Simulacron jar hasn't been specified or C* version is 2.0")
@@ -383,15 +386,15 @@ def get_node(node_id):
     return CCM_CLUSTER.nodes['node%s' % node_id]
 
 
-def use_multidc(dc_list, workloads=[]):
+def use_multidc(dc_list, workloads=None):
     use_cluster(MULTIDC_CLUSTER_NAME, dc_list, start=True, workloads=workloads)
 
 
-def use_singledc(start=True, workloads=[], use_single_interface=USE_SINGLE_INTERFACE):
+def use_singledc(start=True, workloads=None, use_single_interface=USE_SINGLE_INTERFACE):
     use_cluster(CLUSTER_NAME, [3], start=start, workloads=workloads, use_single_interface=use_single_interface)
 
 
-def use_single_node(start=True, workloads=[], configuration_options={}, dse_options={}):
+def use_single_node(start=True, workloads=None, configuration_options=None, dse_options=None):
     use_cluster(SINGLE_NODE_CLUSTER_NAME, [1], start=start, workloads=workloads,
                 configuration_options=configuration_options, dse_options=dse_options)
 
@@ -453,10 +456,11 @@ def start_cluster_wait_for_up(cluster):
 
 
 def use_cluster(cluster_name, nodes, ipformat=None, start=True, workloads=None, set_keyspace=True, ccm_options=None,
-                configuration_options={}, dse_options={}, use_single_interface=USE_SINGLE_INTERFACE):
+                configuration_options=None, dse_options=None, use_single_interface=USE_SINGLE_INTERFACE):
+    configuration_options = configuration_options or {}
+    dse_options = dse_options or {}
+    workloads = workloads or []
     dse_cluster = True if DSE_VERSION else False
-    if not workloads:
-        workloads = []
 
     if ccm_options is None and DSE_VERSION:
         ccm_options = {"version": CCM_VERSION}
@@ -595,13 +599,16 @@ def use_cluster(cluster_name, nodes, ipformat=None, start=True, workloads=None,
                 wait_for_node_socket(node, 300)
             log.debug("Binary ports are open")
             if set_keyspace:
-                setup_keyspace(ipformat=ipformat)
+                args = {"ipformat": ipformat}
+                if use_single_interface:
+                    args["port"] = DEFAULT_SINGLE_INTERFACE_PORT
+                setup_keyspace(**args)
     except Exception:
         log.exception("Failed to start CCM cluster; removing cluster.")
 
         if os.name == "nt":
             if CCM_CLUSTER:
-                for node in six.itervalues(CCM_CLUSTER.nodes):
+                for node in CCM_CLUSTER.nodes.items():
                     os.system("taskkill /F /PID " + str(node.pid))
         else:
             call(["pkill", "-9", "-f", ".ccm"])
@@ -694,7 +701,7 @@ def drop_keyspace_shutdown_cluster(keyspace_name, session, cluster):
         cluster.shutdown()
 
 
-def setup_keyspace(ipformat=None, wait=True, protocol_version=None):
+def setup_keyspace(ipformat=None, wait=True, protocol_version=None, port=9042):
     # wait for nodes to startup
     if wait:
         time.sleep(10)
@@ -705,9 +712,9 @@ def setup_keyspace(ipformat=None, wait=True, protocol_version=None):
         _protocol_version = PROTOCOL_VERSION
 
     if not ipformat:
-        cluster = TestCluster(protocol_version=_protocol_version)
+        cluster = TestCluster(protocol_version=_protocol_version, port=port)
     else:
-        cluster = TestCluster(contact_points=["::1"], protocol_version=_protocol_version)
+        cluster = TestCluster(contact_points=["::1"], protocol_version=_protocol_version, port=port)
     session = cluster.connect()
 
     try:
