@@ -12,20 +12,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest  # noqa
+import unittest
 
 from collections import deque
 from copy import copy
-from mock import Mock, call, patch
+from mock import Mock, call, patch, ANY
 import time
 from uuid import uuid4
 import logging
 import warnings
 from packaging.version import Version
 
+import six
 import cassandra
 from cassandra.cluster import NoHostAvailable, ExecutionProfile, EXEC_PROFILE_DEFAULT, ControlConnection, Cluster
 from cassandra.concurrent import execute_concurrent
@@ -150,7 +148,7 @@ class ClusterTests(unittest.TestCase):
         get_node(1).pause()
         cluster = TestCluster(contact_points=['127.0.0.1'], connect_timeout=1)
 
-        with self.assertRaisesRegexp(NoHostAvailable, "OperationTimedOut\('errors=Timed out creating connection \(1 seconds\)"):
+        with self.assertRaisesRegex(NoHostAvailable, "OperationTimedOut\('errors=Timed out creating connection \(1 seconds\)"):
             cluster.connect()
         cluster.shutdown()
 
@@ -538,7 +536,7 @@ class ClusterTests(unittest.TestCase):
             # cluster agreement wait used for refresh
             original_meta = c.metadata.keyspaces
             start_time = time.time()
-            self.assertRaisesRegexp(Exception, r"Schema metadata was not refreshed.*", c.refresh_schema_metadata)
+            self.assertRaisesRegex(Exception, r"Schema metadata was not refreshed.*", c.refresh_schema_metadata)
             end_time = time.time()
             self.assertGreaterEqual(end_time - start_time, agreement_timeout)
             self.assertIs(original_meta, c.metadata.keyspaces)
@@ -575,7 +573,7 @@ class ClusterTests(unittest.TestCase):
             # refresh wait overrides cluster value
             original_meta = c.metadata.keyspaces
             start_time = time.time()
-            self.assertRaisesRegexp(Exception, r"Schema metadata was not refreshed.*", c.refresh_schema_metadata,
+            self.assertRaisesRegex(Exception, r"Schema metadata was not refreshed.*", c.refresh_schema_metadata,
                                     max_schema_agreement_wait=agreement_timeout)
             end_time = time.time()
             self.assertGreaterEqual(end_time - start_time, agreement_timeout)
@@ -1481,7 +1479,18 @@ class DontPrepareOnIgnoredHostsTest(unittest.TestCase):
         # the length of mock_calls will vary, but all should use the unignored
         # address
         for c in cluster.connection_factory.mock_calls:
-            self.assertEqual(call(DefaultEndPoint(unignored_address)), c)
+            # PYTHON-1287
+            #
+            # Cluster._prepare_all_queries() will call connection_factory _without_ the
+            # on_orphaned_stream_released arg introduced in commit
+            # 387150acc365b6cf1daaee58c62db13e4929099a.  The reconnect handler for the
+            # downed node _will_ add this arg when it tries to rebuild it's conn pool, and
+            # whether this occurs while running this test amounts to a race condition.  So
+            # to cover this case we assert one of two call styles here... the key is that
+            # the _only_ address we should see is the unignored_address.
+            self.assertTrue( \
+                c == call(DefaultEndPoint(unignored_address)) or \
+                c == call(DefaultEndPoint(unignored_address), on_orphaned_stream_released=ANY))
         cluster.shutdown()
 
 
