@@ -15,10 +15,7 @@ import os
 from cassandra.concurrent import execute_concurrent
 from cassandra import DriverException
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest  # noqa
+import unittest
 import logging
 from cassandra import ProtocolVersion
 from cassandra import ConsistencyLevel, Unavailable, InvalidRequest, cluster
@@ -37,7 +34,6 @@ import random
 import re
 
 import mock
-import six
 
 
 log = logging.getLogger(__name__)
@@ -463,10 +459,10 @@ class ForcedHostIndexPolicy(RoundRobinPolicy):
         try:
             host = [live_hosts[self.host_index_to_use]]
         except IndexError as e:
-            six.raise_from(IndexError(
+            raise IndexError(
                 'You specified an index larger than the number of hosts. Total hosts: {}. Index specified: {}'.format(
                     len(live_hosts), self.host_index_to_use
-                )), e)
+                )) from e
         return host
 
 
