@@ -26,8 +26,7 @@ import io
 import random
 from functools import wraps
 from itertools import cycle
-import six
-from six import binary_type, BytesIO
+from io import BytesIO
 from mock import Mock
 
 import errno
@@ -37,10 +36,7 @@ import os
 from socket import error as socket_error
 import ssl
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest # noqa
+import unittest
 
 import time
 
@@ -205,7 +201,7 @@ class ReactorTestMixin(object):
         return setattr(connection, self.socket_attr_name, obj)
 
     def make_header_prefix(self, message_class, version=2, stream_id=0):
-        return binary_type().join(map(uint8_pack, [
+        return bytes().join(map(uint8_pack, [
             0xff & (HEADER_DIRECTION_TO_CLIENT | version),
             0,  # flags (compression)
             stream_id,
@@ -233,7 +229,7 @@ class ReactorTestMixin(object):
         write_string(buf, msg)
         return buf.getvalue()
 
-    def make_msg(self, header, body=binary_type()):
+    def make_msg(self, header, body=bytes()):
         return header + uint32_pack(len(body)) + body
 
     def test_successful_connection(self):
@@ -292,7 +288,7 @@ class ReactorTestMixin(object):
         c.process_io_buffer = Mock()
 
         def chunk(size):
-            return six.b('a') * size
+            return b'a' * size
 
         buf_size = c.in_buffer_size
 
@@ -439,7 +435,7 @@ class ReactorTestMixin(object):
 
         self.get_socket(c).recv.return_value = message[1:]
         c.handle_read(*self.null_handle_function_args)
-        self.assertEqual(six.binary_type(), c._io_buffer.io_buffer.getvalue())
+        self.assertEqual(bytes(), c._io_buffer.io_buffer.getvalue())
 
         # let it write out a StartupMessage
         c.handle_write(*self.null_handle_function_args)
@@ -466,7 +462,7 @@ class ReactorTestMixin(object):
         # ... then read in the rest
         self.get_socket(c).recv.return_value = message[9:]
         c.handle_read(*self.null_handle_function_args)
-        self.assertEqual(six.binary_type(), c._io_buffer.io_buffer.getvalue())
+        self.assertEqual(bytes(), c._io_buffer.io_buffer.getvalue())
 
         # let it write out a StartupMessage
         c.handle_write(*self.null_handle_function_args)
@@ -502,7 +498,7 @@ class ReactorTestMixin(object):
             for i in range(1, 15):
                 c.process_io_buffer.reset_mock()
                 c._io_buffer._io_buffer = io.BytesIO()
-                message = io.BytesIO(six.b('a') * (2**i))
+                message = io.BytesIO(b'a' * (2**i))
 
                 def recv_side_effect(*args):
                     if random.randint(1,10) % 3 == 0:
