@@ -12,12 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest  # noqa
-
-import six
+import unittest
 
 from concurrent.futures import ThreadPoolExecutor
 from mock import Mock, ANY, call
@@ -51,7 +46,7 @@ class MockMetadata(object):
 
     def get_host(self, endpoint_or_address, port=None):
         if not isinstance(endpoint_or_address, EndPoint):
-            for host in six.itervalues(self.hosts):
+            for host in self.hosts.values():
                 if (host.address == endpoint_or_address and
                         (port is None or host.broadcast_rpc_port is None or host.broadcast_rpc_port == port)):
                     return host
@@ -529,7 +524,7 @@ class ControlConnectionTest(unittest.TestCase):
         self.assertEqual(self.cluster.added_hosts[0].broadcast_rpc_address, "192.168.1.3")
         self.assertEqual(self.cluster.added_hosts[0].broadcast_rpc_port, 555)
         self.assertEqual(self.cluster.added_hosts[0].broadcast_address, "10.0.0.3")
-        self.assertEquals(self.cluster.added_hosts[0].broadcast_port, 666)
+        self.assertEqual(self.cluster.added_hosts[0].broadcast_port, 666)
         self.assertEqual(self.cluster.added_hosts[0].datacenter, "dc1")
         self.assertEqual(self.cluster.added_hosts[0].rack, "rack1")
 
@@ -549,7 +544,7 @@ class ControlConnectionTest(unittest.TestCase):
         self.assertEqual(self.cluster.added_hosts[0].broadcast_rpc_address, "192.168.1.3")
         self.assertEqual(self.cluster.added_hosts[0].broadcast_rpc_port, None)
         self.assertEqual(self.cluster.added_hosts[0].broadcast_address, "10.0.0.3")
-        self.assertEquals(self.cluster.added_hosts[0].broadcast_port, None)
+        self.assertEqual(self.cluster.added_hosts[0].broadcast_port, None)
         self.assertEqual(self.cluster.added_hosts[0].datacenter, "dc1")
         self.assertEqual(self.cluster.added_hosts[0].rack, "rack1")
 
